@@ -12,6 +12,7 @@ import functools
 import heapq
 import collections.abc
 import queue
+from typing import Iterable, Any
 
 import inflect
 import more_itertools
@@ -1127,18 +1128,18 @@ def _swap_on_miss(partition_result):
 
 def partition_dict(items, key):
     """
-    Given an ordered dictionary of items and a key in that dict,
-    return an ordered dict of items before, the keyed item, and
-    an ordered dict of items after.
+    Given a dictionary of items and a key in that dict,
+    return another dict of items before, the keyed item, and
+    the dict of items after.
 
-    >>> od = collections.OrderedDict(zip(range(5), 'abcde'))
+    >>> od = dict(zip(range(5), 'abcde'))
     >>> before, item, after = partition_dict(od, 3)
     >>> before
-    OrderedDict([(0, 'a'), (1, 'b'), (2, 'c')])
+    {0: 'a', 1: 'b', 2: 'c'}
     >>> item
     'd'
     >>> after
-    OrderedDict([(4, 'e')])
+    {4: 'e'}
 
     Like string.partition, if the key is not found in the items,
     the before will contain all items, item will be None, and
@@ -1146,10 +1147,10 @@ def partition_dict(items, key):
 
     >>> before, item, after = partition_dict(od, -1)
     >>> before
-    OrderedDict([(0, 'a'), ..., (4, 'e')])
+    {0: 'a', ..., 4: 'e'}
     >>> item
-    >>> list(after)
-    []
+    >>> after
+    {}
     """
 
     def unmatched(pair):
@@ -1158,8 +1159,8 @@ def partition_dict(items, key):
 
     items_iter = iter(items.items())
     item = items.get(key)
-    left = collections.OrderedDict(itertools.takewhile(unmatched, items_iter))
-    right = collections.OrderedDict(items_iter)
+    left = dict(itertools.takewhile(unmatched, items_iter))
+    right = dict(items_iter)
     return left, item, right
 
 
@@ -1167,6 +1168,7 @@ def ensure_unique(iterable, key=lambda x: x):
     """
     Wrap an iterable to raise a ValueError if non-unique values are encountered.
 
+    >>> from more_itertools import consume
     >>> list(ensure_unique('abc'))
     ['a', 'b', 'c']
     >>> consume(ensure_unique('abca'))
@@ -1182,3 +1184,75 @@ def ensure_unique(iterable, key=lambda x: x):
             raise ValueError(f"Duplicate element {element!r} encountered.")
         seen_add(k)
         yield element
+
+
+def accumulate(increments):
+    """
+    Accumulate values in the iterable into a new iterable
+    of the same length.
+
+    >>> list(accumulate([1, 2, 3]))
+    [1, 3, 6]
+    >>> list(accumulate([0.5, -1, 20]))
+    [0.5, -0.5, 19.5]
+    >>> list(accumulate([]))
+    []
+    >>> list(accumulate([42]))
+    [42]
+
+    Accepts any objects that are summable.
+
+    >>> list(accumulate('abcde'))
+    ['a', 'ab', 'abc', 'abcd', 'abcde']
+    """
+    items_ = iter(increments)
+    try:
+        value = next(items_)
+    except StopIteration:
+        return
+    yield value
+    for item in items_:
+        value += item
+        yield value
+
+
+def find_subseq(seq: Iterable[Any], cand: Iterable[Any]):
+    """Find cand in seq.
+
+    Args:
+        seq: iterable of items to be searched
+        cand: iterable of items that must match
+
+    Returns:
+        The index where cand can be found in seq or None.
+
+    >>> find_subseq([-1, 0, 1, 2], [1, 2])
+    2
+    >>> find_subseq([-1, 0, 1, 2], [0, 2])
+    >>> find_subseq([-1, 0, 1, 2], [2, 1])
+    >>> find_subseq([-1, 0, 1, 2], [])
+    Traceback (most recent call last):
+    ...
+    ValueError: window size must be at least 1
+    """
+    cand = tuple(cand)
+
+    def check(*window):
+        return window == cand
+
+    match_indexes = more_itertools.locate(seq, check, window_size=len(cand))
+    return next(match_indexes, None)
+
+
+def summarize(items: Iterable, **bin_checks):
+    """
+    >>> is_str = lambda item: isinstance(item, str)
+    >>> is_int = lambda item: isinstance(item, int)
+    >>> summarize(['a', 'b', 20], strings=is_str, ints=is_int)
+    {'strings': 2, 'ints': 1}
+    """
+    counters = {name: itertools.count() for name in bin_checks}
+    for item, check in itertools.product(items, bin_checks):
+        if bin_checks[check](item):
+            next(counters[check])
+    return {name: next(counter) for name, counter in counters.items()}
